@@ -1,6 +1,7 @@
 OC.L10N.register(
     "forms",
     {
+    "Timestamp of data load" : "Пазнака часу загрузкі даных",
     "No" : "Не",
     "Yes" : "Так",
     "Question" : "Пытанне",
@@ -13,6 +14,7 @@ OC.L10N.register(
     "Results" : "Вынікі",
     "Cancel" : "Скасаваць",
     "Options" : "Варыянты",
+    "Page number" : "Нумар старонкі",
     "Delete answer" : "Выдаліць адказ",
     "Required" : "Абавязкова",
     "Copy question" : "Капіяваць пытанне",
@@ -57,6 +59,7 @@ OC.L10N.register(
     "Text" : "Тэкст",
     "Phone number" : "Нумар тэлефона",
     "Email address" : "Адрас электроннай пошты",
+    "Number" : "Нумар",
     "Uploading …" : "Запампоўванне …"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
